@@ -26,8 +26,12 @@ class Site(Site):
         abstract = dd.is_abstract_model(__name__, 'Site')
 
     def get_change_observers(self, ar=None):
-        action = ar.bound_action.action if ar.bound_action else None
-        if ar is not None and isinstance(action, CreateRow) and issubclass(ar.actor.model.Ticket):
+        # action = ar.bound_action.action if ar.bound_action else None
+        # if ar is not None and isinstance(action, CreateRow) and issubclass(ar.actor.model, Ticket):
+        if False:
+            # 20210928 The idea was to notify only triagers when a new site was
+            # created for a team. We can throw this away, seems that this made
+            # some sense a long time ago when we didn't yet have teams.
             subs = rt.models.groups.Group.objects.filter(site=ar.selected_rows[-1].site)
             #subs = rt.models.tickets.Subscription.objects.filter(site=ar.selected_rows[-1].site)
             for s in subs.members.all():
